<?php
/*
Plugin Name: Category Related Posts Widget
Plugin URI: http://www.nsauditor.com/wordpress/category-related-posts-widget
Description: The Category Related Posts Widget shows a list of posts with similar categories to the current post.
Author: Varuzhan Kankanyan
Author URI: http://www.nsauditor.com
Version: 1.0.1
License: GNU General Public License version 2.0 or above
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

class CategoryRelatedPostsWidget extends WP_Widget
{
	function CategoryRelatedPostsWidget()
	{
		parent::WP_Widget( false, $name = 'Category Related Posts Widget' );
	}
	
	function widget($args, $instance)
	{
		if(!is_single()) return;
        extract( $args );
		$title = ( $instance['title'] ) ? $instance['title'] : 'Related Topics';
		$count = ( $instance['count'] ) ? $instance['count'] : 3;
        echo $before_widget;
        $widget_title = '<h3>'.$before_title . $title . $after_title.'</h3>';

        // Display Related Posts
        displayRelatedPosts($widget_title,(int)$count);
        echo $after_widget;

		
	}
	function update($new_instance,$old_instance)
	{
      $instance = $old_instance;

      $instance['title'] = strip_tags($new_instance['title']);
      $instance['count'] = strip_tags($new_instance['count']);	  
		
		return $new_instance;
	}
	
	function form($instance)
	{
		?>		
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">
				<?php _e( 'Title' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>" />
			</label>
		</p>	
		
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>">
				<?php _e('Posts to display'); ?>:
				<input style="text-align: center;" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" type="text" value="<?php echo absint($instance['count']); ?>" size='3' />
			</label>
		</p>		
		
		<?php	
	}
}

function displayRelatedPosts($widget_title,$post_count)
{
	$id = get_the_id();
	$content = '';
	
	$content .=$widget_title;
	$terms = get_the_terms($id,'category');
	$cats = array();
	foreach($terms as $term){
		$cats[]=$term->cat_ID;
	}
	
	$query = new WP_Query(
		array(
			'posts_per_page'=>$post_count,
			'category__in'=>$cats,
			'order_by'=>'rand',
			'post__not_in'=>array($id)
		)
	);
	
	if($query->have_posts()){
		$content .= '
		<ul>';
		while($query->have_posts()){
			$query->the_post();
			$content .= '
			<li>
				<a href="'.get_permalink(get_the_id()) .'">'.get_the_title().'</a>
			</li>';
		}
		$content .= '</ul>';
		wp_reset_query();
	}
	
	echo $content;

}

add_action('widgets_init','categoryRelatedPostsWidgetInit');

function categoryRelatedPostsWidgetInit()
{
	register_widget('CategoryRelatedPostsWidget');
}

?>